#
# spec file for package chessx
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           chessx
Version:        1.5.4
Release:        lp152.1.3
Summary:        Chess database
License:        GPL-2.0-only
Group:          Amusements/Games/Board/Chess
URL:            http://chessx.sourceforge.net
Source0:        https://sourceforge.net/projects/chessx/files/chessx/%{version}/chessx-%{version}.tgz
# PATCH-FIX-UPSTREAM chessx-translations.patch aloisio@gmx.com -- remove unused translations
Patch0:         chessx-translations.patch
# PATCH-FEATURE-UPSTREAM chessx-install.patch aloisio@gmx.com -- make install work on linux
Patch1:         chessx-install.patch
# PATCH-FEATURE-OPENSUSE chessx-use_system_quazip.patch
Patch2:         chessx-use_system_quazip.patch
BuildRequires:  fdupes
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5TextToSpeech)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
%if (0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200)
BuildRequires:  pkgconfig(quazip)
%endif
BuildRequires:  pkgconfig(zlib)

%description
ChessX is a chess database. With ChessX, you can browse, edit and
analyze a collection of chess games.

* Load and save PGN files
* Work with multiple databases simultaneously
* Browse games, including variations
* Enter moves, variations, comments
* Play games in training mode or play out games against an engine
* Setup board, copy/paste FEN, merge games
* Display opening tree for current position
* Analyze using UCI and Winboard/Xboard Chess engines
* Observe and play games on FICS

%prep
%autosetup -N
%patch0 -p1
%patch1 -p1
%if (0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200)
%patch2 -p1
%endif
chmod -x data/images/circle_*.svg

%build
%qmake5
%make_build

%install
%qmake5_install
find %{buildroot} -size 0 -delete
%fdupes %{buildroot}

%files
%license COPYING
%doc ChangeLog README.developers TODO
%dir %{_datadir}/%{name}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/data
%{_datadir}/pixmaps/%{name}.png

%changelog
* Sat May  9 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.4
  * New feature: blunder checking
  * New feature: Speak moves
  * New feature: Refactor complete database
  * Changed: Command-Key to force query for promotion dialog
    (instead of Meta)
  * Bugfix: Undo setting up board required two steps
  * Bugfix: Clearing database was broken
  * Bugfix: entering nags/null movees via keyboard
- Add chessx-translations.patch, chessx-install.patch and
  chessx-use_system_quazip.patch
* Mon May  6 2019 Luigi Baldoni <aloisio@gmx.com>
- New tarball with Qt 5.9 fix (no version change)
* Sun May  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.0
  New Features:
  * Provide multi-selection for the database list view
  * Load favorite databases at startup
  * Read Chessbase Books (ctg)
  * Read Arena Books (.abk)
  * Drag databases into list of games
  * Dark Theme
  * FICS console with commandline
  * Syzygy 7 men online tablebase
  * Change font size via mouse wheel
  * Search depth for analysis
  * Filter operation from gamelist
  * Allow user-provided ECO files
  * Save dialog allows to store extra tags
  * Restrict search to start of word / end of word
  * Edit shortcuts by pressing key
  * Annotations beneath board view
  * Turn board for given player
  * Send database to Mail-Client
  * Show analysis of position with one piece moved
  * Merge internal and external themes, new option to scale
    board images
  Bug Fixes:
  * Reduced Memory Footprint
  * Removing a sub-variation kept some invisble moves
  * Internal engine produced silly suggestions in case of a check
  * Parse more than one tag in a line
  * Changing book in analysis should update moves immediately
  * Do not list read-only databases as copy targets
  * Update game list columns after leaving preferences
  * Console output and event info lacks termination of bold text
  * Avoid empty annotation when merging a game
  * "New Game" disabled after loading game
  * Invalid notation when inserting line from analysis
  * Puzzle mode not terminated properly
  * Performance reading Polyglot positions
  * Disconnecting a FICS session leaked some memory
  * Progress bar missing occasionally
  Changes:
  * Draw arrows with right mouse
  * Index file format updated
  * Support engines with state issues
  * time representation to ISO format
  * Do not ask to save deleted games
  * Copy current game instead of first selected game
  * Kick out hotkeys for database changes
  * Analysis and Endgametables display localised piece strings
  * Books support localized piece representation
  * Accept PGN with obscure RAVs
  * Index file format stores data size
  * If loading modifies db, mark db as changed
  * Always use DefaultDataPath (instead of last used folder) for
    Save Dialogs
  * Index file version
- Dropped chessx-Qt511.patch (no longer necessary)
* Mon Jun 11 2018 aloisio@gmx.com
- Added chessx-Qt511.patch to fix build failure with Qt 5.11
* Fri Apr 14 2017 aloisio@gmx.com
- Update to version 1.4.6
  * New feature: Indicate underprotected pieces
  * New feature: Indicate covered squares
  * New feature: Book building progress
  * Bugfix: Annotations remain visible after adding variation
  * Bugfix: Saving games on non-current database
  * Bugfix: Name of downloaded files
  * Bugfix: Crash engine accessing closed book
  * Changed: Use more threads for book building
* Fri Apr  7 2017 aloisio@gmx.com
- Update to version 1.4.4
  * New feature: Game time for 2-player mode
  * New Feature: Drag databases into list of games
  * New feature: Copy lists to IMG/HTML in Clipboard
  * New feature: Workaround UCI option issue in Stockfish 8
  * New feature: Extended polyglot book generation
  * New feature: Reverse moving with mouse
  * New feature: Dragging piece with CTRL+SHIFT asks main engine /
    tablebase for eval
  * New feature: FICS with Clock above / below board
  * New feature: cz language pack
  * New feature: Message History
  * New feature: Rendering for Retina displays
  * New feature: Indicate number of pieces in Board Setup
  * New feature: Indicate King in check
  * New feature: Paint Tools
  * New feature: Show possible targets for selected piece
  * New feature: FICS rematch
  * New feature: Search Help pages for texts
  * New feature: FICS requests with color
  * New feature: Show all good tablebase moves
  * Bugfix: UCI_Chess960 occasionally not sent to Engine
  * Bugfix: Handling of UCI empty string tag
  * Bugfix: Renaming a player / event tag gave inconsistent index
    in case of existing target tag
  * Bugfix: Restoration of floating docks
  * Bugfix: Chess960 castling direction wrong
  * Bugfix: Chess960 with UCI engines
  * Bugfix: Resizing the application would sometimes fail
  * Bugfix: Matchparameter Dialog misplaced
  * Bugfix: Premoving allowed moving opponent pieces
  * Changed: Analysis time up to 10 minutes
  * Changed: Bundle Stockfish 8
  * Changed: Icons in context menus
  * Changed: Matchparameter Dialog
  * Changed: Square annotations
  * Changed: Tock at 30..20..10s before Timeout
  * Changed: Move some preferences onto toolbar
* Tue Mar 14 2017 jengelh@inai.de
- Trim redundant mentions from description
* Sun Oct  9 2016 aloisio@gmx.com
- Initial version 1.4.0
